Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 82567)
+++ apps/app_voicemail.c	(working copy)
@@ -572,6 +572,7 @@
 static int maxgreet;
 static int skipms;
 static int maxlogins;
+static int movetodeleted=0;	/* Move deleted msgs to Deleted Folder */
 
 /*! Poll mailboxes for changes since there is something external to
  *  app_voicemail that may change them. */
@@ -2299,6 +2300,7 @@
 		"Cust3",
 		"Cust4",
 		"Cust5",
+		"Deleted",
 	};
 	return (id >= 0 && id < (sizeof(msgs)/sizeof(msgs[0]))) ? msgs[id] : "Unknown";
 }
@@ -5205,7 +5207,17 @@
 			make_file(vms->fn, sizeof(vms->fn), vms->curdir, x);
 			if (EXISTS(vms->curdir, x, vms->fn, NULL))
 				DELETE(vms->curdir, x, vms->fn);
-		} 
+		} else if (vms->deleted[x] && movetodeleted) {
+			/* Move to deleted folder */
+			res = save_to_folder(vmu, vms, x, 10);
+			if (res == ERROR_LOCK_PATH) {
+				/* If save failed do not delete the message */
+				vms->deleted[x] = 0;
+				vms->heard[x] = 0;
+				--x;
+				ast_log(LOG_WARNING,"Failed to Move msg to Deleted Folder\n");
+			}
+		}
 	} 
 
 	/* Delete ALL remaining messages */
@@ -8314,6 +8326,11 @@
 		}
 		ast_set2_flag((&globalflags), ast_true(val), VM_SKIPAFTERCMD);
 
+		if ((val = ast_variable_retrieve(cfg, "general", "movetodeleted"))) { 
+			ast_debug(1,"Move to Deleted enabled globally '%s'\n",val);
+			movetodeleted = ast_true(val);
+		}
+
 		if ((val = ast_variable_retrieve(cfg, "general", "dialout"))) {
 			ast_copy_string(dialcontext, val, sizeof(dialcontext));
 			ast_debug(1, "found dialout context: %s\n", dialcontext);
Index: configs/voicemail.conf.sample
===================================================================
--- configs/voicemail.conf.sample	(revision 82567)
+++ configs/voicemail.conf.sample	(working copy)
@@ -51,6 +51,14 @@
 ; Max number of failed login attempts
 maxlogins=3
 ;
+; Move deleted msgs to the Deleted Folder. Note: the Deleted folder is not
+; accessable from Comedian Mail; it's designed to be accessed by an
+; external program but it might just save your bacon when your CEO deletes
+; an important voicemail and demands that you get it back.
+; Default off
+;movetodeleted=no
+;
+;
 ; User context is where entries from users.conf are registered.  The
 ; default value is 'default'
 ;
